@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11928 2020-02-17 04:02:19Z Trista $
+# $Id: models.py 11904 2020-02-05 13:38:19Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $
-# $Date: 2020-02-17 13:02:19 +0900 (週一, 17 二月 2020) $
-# $Revision: 11928 $
+# $Author: Lavender $
+# $Date: 2020-02-05 21:38:19 +0800 (週三, 05 二月 2020) $
+# $Revision: 11904 $
 
 from functools import wraps
 from django import forms
@@ -25,14 +25,10 @@ from aldryn_categories.models import Category
 from aldryn_newsblog.models import Article
 from aldryn_newsblog import models as newsblogModels
 from taggit.models import Tag
-from djangocms_forms.models import FormDefinition
-from filer.models.filemodels import File
 
 from Iuppiter.DjangoUtil import DJANGO_VERSION
 from Zephyrus.blog_extension import settings as _settings
 
-
-
 METHODS = [
     ('or',  _('OR')),
     ('and',  _('AND')),
@@ -186,12 +182,3 @@ utilities.get_plugin_index_data = get_plugin_index_data
 newsblogModels.get_plugin_index_data = get_plugin_index_data
 
 
-class Action(FormDefinition):
-    file = models.ForeignKey(File)
-
-class ActionRecord(models.Model):
-    action = models.ForeignKey(Action)
-    token = models.CharField(max_length=80)
-    email = models.CharField(max_length=500)
-    count = models.IntegerField(default=0)
-    url = models.CharField(max_length=500)
